@@ -443,7 +443,7 @@ export function aggregateData(data, aggregation) {
 
 // The aggregation model
 export const aggregationTypes = parseSchemaMarkdown(`\
-group "Aggregation"
+group "data"
 
 
 # A data aggregation specification
