@@ -1427,7 +1427,7 @@ function regexMatchGroups(match) {
 
 // The regex match model
 export const regexMatchTypes = parseSchemaMarkdown(`\
-group "RegexMatch"
+group "regex"
 
 
 # A regex match model
@@ -1522,7 +1522,7 @@ const regexSplitArgs = valueArgsModel([
 // $doc: Parse the [Schema Markdown](https://craigahobbs.github.io/schema-markdown-js/language/) text
 // $arg lines...: The [Schema Markdown](https://craigahobbs.github.io/schema-markdown-js/language/)
 // $arg lines...: text lines (may contain nested arrays of un-split lines)
-// $return: The schema's [type model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types')
+// $return: The schema's [type model](https://craigahobbs.github.io/bare-script/model/#var.vName='Types'&var.vURL='')
 function schemaParse(lines) {
     return parseSchemaMarkdown(lines);
 }
@@ -1533,9 +1533,9 @@ function schemaParse(lines) {
 // $doc: Parse the [Schema Markdown](https://craigahobbs.github.io/schema-markdown-js/language/) text with options
 // $arg lines: The array of [Schema Markdown](https://craigahobbs.github.io/schema-markdown-js/language/)
 // $arg lines: text lines (may contain nested arrays of un-split lines)
-// $arg types: Optional. The [type model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types').
+// $arg types: Optional. The [type model](https://craigahobbs.github.io/bare-script/model/#var.vName='Types'&var.vURL='').
 // $arg filename: Optional (default is ""). The file name.
-// $return: The schema's [type model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types')
+// $return: The schema's [type model](https://craigahobbs.github.io/bare-script/model/#var.vName='Types'&var.vURL='')
 function schemaParseEx(args) {
     const [lines, typesArg, filename] = valueArgsValidate(schemaParseExArgs, args);
     const linesType = valueType(lines);
@@ -1556,8 +1556,8 @@ const schemaParseExArgs = valueArgsModel([
 
 // $function: schemaTypeModel
 // $group: schema
-// $doc: Get the [Schema Markdown Type Model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types')
-// $return: The [Schema Markdown Type Model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types')
+// $doc: Get the [Schema Markdown Type Model](https://craigahobbs.github.io/bare-script/model/#var.vName='Types'&var.vURL='')
+// $return: The [Schema Markdown Type Model](https://craigahobbs.github.io/bare-script/model/#var.vName='Types'&var.vURL='')
 function schemaTypeModel() {
     return typeModel;
 }
@@ -1566,7 +1566,7 @@ function schemaTypeModel() {
 // $function: schemaValidate
 // $group: schema
 // $doc: Validate an object to a schema type
-// $arg types: The [type model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types')
+// $arg types: The [type model](https://craigahobbs.github.io/bare-script/model/#var.vName='Types'&var.vURL='')
 // $arg typeName: The type name
 // $arg value: The object to validate
 // $return: The validated object or null if validation fails
@@ -1585,9 +1585,9 @@ const schemaValidateArgs = valueArgsModel([
 
 // $function: schemaValidateTypeModel
 // $group: schema
-// $doc: Validate a [Schema Markdown Type Model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types')
-// $arg types: The [type model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types') to validate
-// $return: The validated [type model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types')
+// $doc: Validate a [Schema Markdown Type Model](https://craigahobbs.github.io/bare-script/model/#var.vName='Types'&var.vURL='')
+// $arg types: The [type model](https://craigahobbs.github.io/bare-script/model/#var.vName='Types'&var.vURL='') to validate
+// $return: The validated [type model](https://craigahobbs.github.io/bare-script/model/#var.vName='Types'&var.vURL='')
 function schemaValidateTypeModel(args) {
     const [types] = valueArgsValidate(schemaValidateTypeModelArgs, args);
     return validateTypeModel(types);
@@ -1972,7 +1972,7 @@ async function systemFetch([url = null], options) {
 
 // The aggregation model
 export const systemFetchTypes = parseSchemaMarkdown(`\
-group "SystemFetch"
+group "system"
 
 
 # A fetch request model
