@@ -4,10 +4,8 @@
 import {dataTableElements, validateDataTable} from './dataTable.js';
 import {escapeMarkdownText, getMarkdownTitle, parseMarkdown} from '../markdown-model/lib/parser.js';
 import {lineChartElements, validateLineChart} from './lineChart.js';
+import {markdownElements, markdownHeaderId as markdownModelHeaderId} from '../markdown-model/lib/elements.js';
 import {valueArgsModel, valueArgsValidate} from '../bare-script/lib/value.js';
-import {encodeQueryString} from '../schema-markdown/lib/encode.js';
-import {markdownHeaderId as markdownModelHeaderId} from '../markdown-model/lib/elements.js';
-import {schemaMarkdownDoc} from '../schema-markdown-doc/lib/schemaMarkdownDoc.js';
 import {validateElements} from '../element-model/lib/elementModel.js';
 
 
@@ -855,6 +853,33 @@ const localStorageSetArgs = valueArgsModel([
 //
 
 
+// $function: markdownElements
+// $group: Markdown
+// $doc: Generate an element model from a Markdown model
+// $arg markdownModel: The [Markdown model](https://craigahobbs.github.io/markdown-model/model/#var.vName='Markdown')
+// $arg generic: Optional (default is false). If true, render markdown elements in a generic context.
+// $return: The rendered Markdown [element model](https://github.com/craigahobbs/element-model#readme)
+function markdownElementsFn(args, options) {
+    const [markdownModel, generic] = valueArgsValidate(markdownElementsArgs, args);
+
+    // Create the markdown-model options
+    const markdownOptions = {...options.markdownOptions};
+    delete markdownOptions.codeBlocks;
+    if (generic) {
+        delete markdownOptions.copyFn;
+        delete markdownOptions.urlFn;
+        delete markdownOptions.usedHeaderIds;
+    }
+
+    return markdownElements(markdownModel, markdownOptions);
+}
+
+const markdownElementsArgs = valueArgsModel([
+    {'name': 'markdownModel', 'type': 'object'},
+    {'name': 'generic', 'type': 'boolean', 'default': false}
+]);
+
+
 // $function: markdownEscape
 // $group: Markdown
 // $doc: Escape text for inclusion in Markdown text
@@ -921,44 +946,6 @@ const markdownTitleArgs = valueArgsModel([
 ]);
 
 
-//
-// Schema functions
-//
-
-
-// $function: schemaElements
-// $group: Schema
-// $doc: Get a schema type's documentation [element model](https://github.com/craigahobbs/element-model#readme).
-// $doc: Render the element model with the [elementModelRender](#var.vName='elementModelRender') function.
-// $arg types: The [type model](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='Types')
-// $arg typeName: The type name
-// $arg actionURLs: Optional (default is null). The
-// $arg actionURLs: [action URL overrides](https://craigahobbs.github.io/schema-markdown-doc/doc/#var.vName='ActionURL').
-// $arg actionCustom: Optional (default is false). If true, the action has a custom response.
-// $return: The schema type's documentation [element model](https://github.com/craigahobbs/element-model#readme)
-function schemaElements(args, options) {
-    const [types, typeName, actionURLs = null, actionCustom] = valueArgsValidate(schemaElementsArgs, args);
-    const schemaOptions = {
-        'params': encodeQueryString(options.params),
-        'markdownOptions': options.markdownOptions
-    };
-    if (actionURLs !== null) {
-        schemaOptions.actionURLs = actionURLs;
-    }
-    if (actionCustom) {
-        schemaOptions.actionCustom = true;
-    }
-    return schemaMarkdownDoc(types, typeName, schemaOptions);
-}
-
-const schemaElementsArgs = valueArgsModel([
-    {'name': 'types', 'type': 'object'},
-    {'name': 'typeName', 'type': 'string'},
-    {'name': 'actionURLs', 'type': 'array', 'nullable': true},
-    {'name': 'actionCustom', 'type': 'boolean', 'default': false}
-]);
-
-
 //
 // Session storage functions
 //
@@ -1195,12 +1182,12 @@ export const markdownScriptFunctions = {
     localStorageGet,
     localStorageRemove,
     localStorageSet,
+    'markdownElements': markdownElementsFn,
     markdownEscape,
     markdownHeaderId,
     markdownParse,
     markdownPrint,
     markdownTitle,
-    schemaElements,
     sessionStorageClear,
     sessionStorageGet,
     sessionStorageRemove,
